AiProviderFactory class

Factory for configuring an AiProvider from host environment settings.

Looks for FLUTTER_DOCTOR_AI_PROVIDER and FLUTTER_DOCTOR_AI_API_KEY. If non-configured or empty, returns NoAiProvider.

Constructors

AiProviderFactory()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromEnvironment({Map<String, String>? env}) AiProvider
Resolves the provider from environment variables.