FlutterAnalysisResult class

Constructors

FlutterAnalysisResult(List<FlutterIssue> allIssues)

Properties

allIssues List<FlutterIssue>
final
errors List<FlutterIssue>
no setter
hashCode int
The hash code for this object.
no setterinherited
infos List<FlutterIssue>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<FlutterIssue>
no setter

Methods

groups(String severity) List<_Group>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited