EvidenceCollector class

Collects EvidenceItems from the available project and environment data.

Called by runDoctor to build the evidence list before passing it to RootCauseEngine.

Constructors

EvidenceCollector()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collect(String? flutterVersion, String? dartVersion, String? channel, String? javaVersion, String? androidSdkPath, String? agpVersion, String? gradleVersion, String? kotlinVersion, int? compileSdk, int? targetSdk, int? minSdk) List<EvidenceItem>
Builds evidence items from toolchain and environment info.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited