IssueSummary class

A compact summary of one prioritized analyzer rule group.

Constructors

IssueSummary({required String rule, required String priority, required String category, required int occurrenceCount, required String exampleMessage, required int fileCount})
const

Properties

category String
final
exampleMessage String
final
fileCount int
final
hashCode int
The hash code for this object.
no setterinherited
occurrenceCount int
final
priority String
final
rule String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited