RootCauseSummary class

A compact summary of one root cause candidate.

Constructors

RootCauseSummary({required String title, required String summary, required String priority, required String confidence, required int occurrenceCount, required int affectedFileCount, List<String> affectedFiles = const [], required List<String> relatedRules, required List<String> evidenceSummary})
const

Properties

affectedFileCount int
final
affectedFiles List<String>
final
confidence String
final
evidenceSummary List<String>
final
hashCode int
The hash code for this object.
no setterinherited
occurrenceCount int
final
priority String
final
relatedRules List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited