AiStatement class
A statement in AI diagnosis with statement type classification.
Constructors
- AiStatement({required String text, required AiStatementType type, bool isSupported = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSupported → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- type → AiStatementType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited