Recommendation class
A recommendation generated by AI based on deterministic evidence.
Constructors
- Recommendation({required String title, required String explanation, required IssuePriority priority, bool isSupported = true, String? rejectionReason})
-
const
Properties
- explanation → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSupported → bool
-
final
- priority → IssuePriority
-
final
- rejectionReason → String?
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited