IssueCategory enum
Values
- correctness → const IssueCategory
- runtimeSafety → const IssueCategory
- compatibility → const IssueCategory
- deprecatedApi → const IssueCategory
- performance → const IssueCategory
- maintainability → const IssueCategory
- style → const IssueCategory
- codeQuality → const IssueCategory
- unknown → const IssueCategory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
Human-readable display name.
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IssueCategory> - A constant List of the values in this enum, in order of their declaration.