IssuePriority enum

Inheritance
Available extensions

Values

critical → const IssuePriority
high → const IssuePriority
medium → const IssuePriority
low → const IssuePriority
info → const IssuePriority
unknown → const IssuePriority

Properties

displayName String
Human-readable name for display.
no setter
emoji String
Short emoji only.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Display label with emoji and name.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortOrder int
Numeric sort order — lower = higher urgency.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String val) IssuePriority
Parses a string into an IssuePriority. Throws FormatException if val is not a valid priority string.

Constants

values → const List<IssuePriority>
A constant List of the values in this enum, in order of their declaration.