models/root_cause library
Classes
- RootCauseCandidate
- A possible root cause derived from deterministic evidence.
Enums
- RootCauseConfidence
- How strongly the deterministic engine can assert a root cause. Only high is used when evidence is unambiguous and multi-sourced. unknown is used when evidence exists but is insufficient to conclude.