summary property
A longer explanation of what the evidence shows. MUST NOT claim causes that are not proven by the evidence.
Implementation
final String summary;
A longer explanation of what the evidence shows. MUST NOT claim causes that are not proven by the evidence.
final String summary;