AndroidToolchainInfo class
Constructors
Properties
- agpVersion → String?
-
final
- compileSdk → int?
-
final
- gradleVersion → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kotlinVersion → String?
-
final
- minSdk → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetSdk → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited