ProjectEvidence class
Constructors
-
ProjectEvidence(EnvironmentInfo environment, AndroidToolchainInfo android, String? javaExecutable, String? minSdkSource, List<
CompatibilitySuggestion> suggestions) -
const
Properties
- android → AndroidToolchainInfo
-
final
- environment → EnvironmentInfo
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- javaExecutable → String?
-
final
- minSdkSource → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
suggestions
→ List<
CompatibilitySuggestion> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited