CompatibilitySuggestion class
Constructors
- CompatibilitySuggestion(String title, EvidenceSeverity severity, String message, String source, String component, String recommendation)
-
const
Properties
- component → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- recommendation → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → EvidenceSeverity
-
final
- source → String
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited